@@ -28,24 +28,27 @@
 #endif
 
 //#include "Environment.h"
-#include <buffy/stringf.h>
 #include <buffy/MailFolder.h>
-#include <buffy/Exception.h>
+#include <buffy/wibble/exception.h>
 #include "CommandlineParser.h"
 
 #include <vector>
+#include <iostream>
 
 using namespace std;
 using namespace buffy;
+using namespace wibble;
 
 static vector<MailFolder> folders;
 
 static void printStats(const MailFolder& f)
 {
-	printf("%.*s: path %.*s, new %d, unread %d, total %d, flagged %d\n",
-			PFSTR(f.name()),
-			PFSTR(f.path()),
-			f.getMsgNew(), f.getMsgUnread(), f.getMsgTotal(), f.getMsgFlagged());
+	cout << f.name() << ": path " << f.path()
+		 << ", new " << f.getMsgNew()
+		 << " unread " << f.getMsgUnread()
+		 << ", total " << f.getMsgTotal()
+		 << ", flagged " << f.getMsgFlagged()
+		 << endl;
 }
 
 class StatsPrinter : public MailFolderConsumer
@@ -127,7 +130,7 @@ int main(int argc, char* argv[])
 						i != folders.end(); i++)
 					if (i->changed())
 					{
-						printf("%.*s changed\n", PFSTR(i->name()));
+						cout << i->name() << " changed" << endl;
 						i->updateStatistics();
 						printStats(*i);
 					}
@@ -136,10 +139,10 @@ int main(int argc, char* argv[])
 		
 		return 0;
 	}
-	catch (Exception& e)
+	catch (wibble::exception::Generic& e)
 	{
 //		fatal_error("%s: %.*s\n", e.type(), PFSTR(e.desc()));
-		fprintf(stderr, "%s: %.*s\n", e.type(), PFSTR(e.desc()));
+		cerr << e.type() << ": " << e.fullInfo() << endl;
 		return 1;
 	}
 }
